Option
------

The kind of a Bitwuzla configuration option.

Options are configured via a :cpp:class:`bitwuzla::Options` instance,
which must be configured before creating a :cpp:class:`bitwuzla::Bitwuzla`
instance.

.. note::

  Some options are labeled as "expert" options. Use with caution.

----

- enum :cpp:enum:`bitwuzla::Option`

----

:code:`namespace bitwuzla {`

.. doxygenenum:: bitwuzla::Option
    :project: Bitwuzla_cpp

:code:`}`

